import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
var __assign = function () {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s)
                if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
function __rest(s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

var styles = {"component":"checkbox__component_1pwvd","start":"checkbox__start_1pwvd","center":"checkbox__center_1pwvd","addons":"checkbox__addons_1pwvd","block":"checkbox__block_1pwvd","box":"checkbox__box_1pwvd","checkedIcon":"checkbox__checkedIcon_1pwvd","s":"checkbox__s_1pwvd","disabled":"checkbox__disabled_1pwvd","inactive":"checkbox__inactive_1pwvd","checked":"checkbox__checked_1pwvd","indeterminate":"checkbox__indeterminate_1pwvd","label":"checkbox__label_1pwvd","hint":"checkbox__hint_1pwvd","focused":"checkbox__focused_1pwvd","content":"checkbox__content_1pwvd","errorMessage":"checkbox__errorMessage_1pwvd","indeterminateLine":"checkbox__indeterminateLine_1pwvd"};
require('./index.css')

var Checkbox = forwardRef(function (_a, ref) {
    var _b;
    var checked = _a.checked, label = _a.label, hint = _a.hint, _c = _a.size, size = _c === void 0 ? 's' : _c, _d = _a.align, align = _d === void 0 ? 'start' : _d, addons = _a.addons, block = _a.block, onChange = _a.onChange, className = _a.className, name = _a.name, disabled = _a.disabled, inactive = _a.inactive, dataTestId = _a.dataTestId, _e = _a.indeterminate, indeterminate = _e === void 0 ? false : _e, error = _a.error, restProps = __rest(_a, ["checked", "label", "hint", "size", "align", "addons", "block", "onChange", "className", "name", "disabled", "inactive", "dataTestId", "indeterminate", "error"]);
    var labelRef = useRef(null);
    var focused = useFocus(labelRef, 'keyboard')[0];
    var handleChange = function (event) {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name: name });
        }
    };
    var errorMessage = typeof error === 'boolean' ? '' : error;
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, (_b = {},
            _b[styles.disabled] = disabled,
            _b[styles.inactive] = inactive,
            _b[styles.checked] = checked,
            _b[styles.indeterminate] = indeterminate,
            _b[styles.focused] = focused,
            _b[styles.block] = block,
            _b)), ref: mergeRefs([labelRef, ref]) },
        React.createElement("input", __assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId }, restProps)),
        React.createElement("span", { className: styles.box },
            checked && React.createElement(CheckedIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
